@@ -7,11 +7,9 @@
 // Export current sdk types for downstream users building with a different sdk version
 pub use solana_program;
 
-pub mod entrypoint;
 pub mod error;
 pub mod instruction;
 pub mod math;
-pub mod processor;
 pub mod pyth;
 pub mod state;
 
